==> igniteui-angular-charts-18.2.0.tgz: package/esm2015/lib/CommodityChannelIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { CommodityChannelIndexIndicatorStrategy } from "./CommodityChannelIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let CommodityChannelIndexIndicator = /*@__PURE__*/ (() => {
    class CommodityChannelIndexIndicator extends StrategyBasedIndicator {
        bj() {
            return new CommodityChannelIndexIndicator();
        }
        get_abv() {
            return new CommodityChannelIndexIndicatorStrategy();
        }
        get abv() {
            return this.get_abv();
        }
        get_ab8() {
            return CommodityChannelIndexIndicator.$;
        }
        get ab8() {
            return this.get_ab8();
        }
        get acg() {
            return typeGetValue(this.c(CommodityChannelIndexIndicator.ach));
        }
        set acg(a) {
            this.h(CommodityChannelIndexIndicator.ach, a);
        }
        ab1() {
            return this.acg;
        }
        aca(a) {
            this.acg = a;
        }
    }
    CommodityChannelIndexIndicator.$t = markType(CommodityChannelIndexIndicator, 'CommodityChannelIndexIndicator', StrategyBasedIndicator.$);
    CommodityChannelIndexIndicator.ach = StrategyBasedIndicator.acd(20, CommodityChannelIndexIndicator.$);
    return CommodityChannelIndexIndicator;
})();

==> igniteui-angular-charts-20.0.0.tgz: package/esm2015/lib/CommodityChannelIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { CommodityChannelIndexIndicatorStrategy } from "./CommodityChannelIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let CommodityChannelIndexIndicator = /*@__PURE__*/ (() => {
    class CommodityChannelIndexIndicator extends StrategyBasedIndicator {
        bk() {
            return new CommodityChannelIndexIndicator();
        }
        get_ab0() {
            return new CommodityChannelIndexIndicatorStrategy();
        }
        get ab0() {
            return this.get_ab0();
        }
        get_acd() {
            return CommodityChannelIndexIndicator.$;
        }
        get acd() {
            return this.get_acd();
        }
        get acl() {
            return typeGetValue(this.c(CommodityChannelIndexIndicator.acm));
        }
        set acl(a) {
            this.h(CommodityChannelIndexIndicator.acm, a);
        }
        ab6() {
            return this.acl;
        }
        acf(a) {
            this.acl = a;
        }
    }
    CommodityChannelIndexIndicator.$t = markType(CommodityChannelIndexIndicator, 'CommodityChannelIndexIndicator', StrategyBasedIndicator.$);
    CommodityChannelIndexIndicator.acm = StrategyBasedIndicator.aci(20, CommodityChannelIndexIndicator.$);
    return CommodityChannelIndexIndicator;
})();
